Struct ConstraintAdjustment
pub struct ConstraintAdjustment(/* private fields */);wayland and Linux only.Expand description
constraint adjustments
The constraint adjustment value define ways the compositor will adjust the position of the surface, if the unadjusted position would result in the surface being partly constrained.
Whether a surface is considered ‘constrained’ is left to the compositor to determine. For example, the surface may be partly outside the compositor’s defined ‘work area’, thus necessitating the child surface’s position be adjusted until it is entirely inside the work area.
The adjustments can be combined, according to a defined precedence: 1) Flip, 2) Slide, 3) Resize.
Implementations
impl ConstraintAdjustment
impl ConstraintAdjustment
pub const None: ConstraintAdjustment
pub const None: ConstraintAdjustment
don’t move the child surface when constrained
Don’t alter the surface position even if it is constrained on some axis, for example partially outside the edge of an output.
pub const SlideX: ConstraintAdjustment
pub const SlideX: ConstraintAdjustment
move along the x axis until unconstrained
Slide the surface along the x axis until it is no longer constrained.
First try to slide towards the direction of the gravity on the x axis until either the edge in the opposite direction of the gravity is unconstrained or the edge in the direction of the gravity is constrained.
Then try to slide towards the opposite direction of the gravity on the x axis until either the edge in the direction of the gravity is unconstrained or the edge in the opposite direction of the gravity is constrained.
pub const SlideY: ConstraintAdjustment
pub const SlideY: ConstraintAdjustment
move along the y axis until unconstrained
Slide the surface along the y axis until it is no longer constrained.
First try to slide towards the direction of the gravity on the y axis until either the edge in the opposite direction of the gravity is unconstrained or the edge in the direction of the gravity is constrained.
Then try to slide towards the opposite direction of the gravity on the y axis until either the edge in the direction of the gravity is unconstrained or the edge in the opposite direction of the gravity is constrained.
pub const FlipX: ConstraintAdjustment
pub const FlipX: ConstraintAdjustment
invert the anchor and gravity on the x axis
Invert the anchor and gravity on the x axis if the surface is constrained on the x axis. For example, if the left edge of the surface is constrained, the gravity is ‘left’ and the anchor is ‘left’, change the gravity to ‘right’ and the anchor to ‘right’.
If the adjusted position also ends up being constrained, the resulting position of the flip_x adjustment will be the one before the adjustment.
pub const FlipY: ConstraintAdjustment
pub const FlipY: ConstraintAdjustment
invert the anchor and gravity on the y axis
Invert the anchor and gravity on the y axis if the surface is constrained on the y axis. For example, if the bottom edge of the surface is constrained, the gravity is ‘bottom’ and the anchor is ‘bottom’, change the gravity to ‘top’ and the anchor to ‘top’.
The adjusted position is calculated given the original anchor rectangle and offset, but with the new flipped anchor and gravity values.
If the adjusted position also ends up being constrained, the resulting position of the flip_y adjustment will be the one before the adjustment.
pub const ResizeX: ConstraintAdjustment
pub const ResizeX: ConstraintAdjustment
horizontally resize the surface
Resize the surface horizontally so that it is completely unconstrained.
pub const ResizeY: ConstraintAdjustment
pub const ResizeY: ConstraintAdjustment
vertically resize the surface
Resize the surface vertically so that it is completely unconstrained.
impl ConstraintAdjustment
impl ConstraintAdjustment
pub const fn empty() -> ConstraintAdjustment
pub const fn empty() -> ConstraintAdjustment
Get a flags value with all bits unset.
pub const fn all() -> ConstraintAdjustment
pub const fn all() -> ConstraintAdjustment
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<ConstraintAdjustment>
pub const fn from_bits(bits: u32) -> Option<ConstraintAdjustment>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> ConstraintAdjustment
pub const fn from_bits_truncate(bits: u32) -> ConstraintAdjustment
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> ConstraintAdjustment
pub const fn from_bits_retain(bits: u32) -> ConstraintAdjustment
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ConstraintAdjustment>
pub fn from_name(name: &str) -> Option<ConstraintAdjustment>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: ConstraintAdjustment) -> bool
pub const fn intersects(&self, other: ConstraintAdjustment) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ConstraintAdjustment) -> bool
pub const fn contains(&self, other: ConstraintAdjustment) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: ConstraintAdjustment)
pub fn insert(&mut self, other: ConstraintAdjustment)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: ConstraintAdjustment)
pub fn remove(&mut self, other: ConstraintAdjustment)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: ConstraintAdjustment)
pub fn toggle(&mut self, other: ConstraintAdjustment)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: ConstraintAdjustment, value: bool)
pub fn set(&mut self, other: ConstraintAdjustment, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: ConstraintAdjustment,
) -> ConstraintAdjustment
pub const fn intersection( self, other: ConstraintAdjustment, ) -> ConstraintAdjustment
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ConstraintAdjustment) -> ConstraintAdjustment
pub const fn union(self, other: ConstraintAdjustment) -> ConstraintAdjustment
The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: ConstraintAdjustment,
) -> ConstraintAdjustment
pub const fn difference( self, other: ConstraintAdjustment, ) -> ConstraintAdjustment
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: ConstraintAdjustment,
) -> ConstraintAdjustment
pub const fn symmetric_difference( self, other: ConstraintAdjustment, ) -> ConstraintAdjustment
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ConstraintAdjustment
pub const fn complement(self) -> ConstraintAdjustment
The bitwise negation (!) of the bits in self, truncating the result.
impl ConstraintAdjustment
impl ConstraintAdjustment
pub const fn iter(&self) -> Iter<ConstraintAdjustment>
pub const fn iter(&self) -> Iter<ConstraintAdjustment>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ConstraintAdjustment>
pub const fn iter_names(&self) -> IterNames<ConstraintAdjustment>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.